@@ -1,12 +1,12 @@
 ;;; magit-annex.el --- Control git-annex from Magit  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2013-2016 Kyle Meyer <kyle@kyleam.com>
+;; Copyright (C) 2013-2017 Kyle Meyer <kyle@kyleam.com>
 
 ;; Author: Kyle Meyer <kyle@kyleam.com>
 ;;         Rémi Vanicat <vanicat@debian.org>
 ;; URL: https://github.com/kyleam/magit-annex
 ;; Keywords: vc tools
-;; Version: 1.3.0
+;; Version: 1.3.1
 ;; Package-Requires: ((cl-lib "0.3") (magit "2.3.0"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -166,8 +166,8 @@ program used to open the unused file."
               (?a "Auto" "--auto"))
   :options  '((?t "To remote" "--to=" magit-read-remote)
               (?f "From remote" "--from=" magit-read-remote)
-              (?n "Number of copies" "--numcopies=" read-from-minibuffer)
-              (?j "Number of jobs" "--jobs=" read-from-minibuffer))
+              (?n "Number of copies" "--numcopies=")
+              (?j "Number of jobs" "--jobs="))
   :max-action-columns 4)
 
 (magit-define-popup magit-annex-sync-popup
@@ -178,7 +178,9 @@ program used to open the unused file."
               (?r "Sync remote" magit-annex-sync-remote))
   :switches '((?c "Content" "--content")
               (?f "Fast" "--fast")
-              (?F "Force" "--force"))
+              (?F "Force" "--force")
+              (?n "Don't commit local changes" "--no-commit"))
+  :options  '((?j "Number of jobs" "--jobs="))
   :default-action 'magit-annex-sync)
 
 (magit-define-popup magit-annex-unused-popup
@@ -189,7 +191,7 @@ program used to open the unused file."
               (?r "Unused in reflog" magit-annex-unused-reflog))
   :switches '((?f "Fast" "--fast"))
   :options '((?f "From remote" "--from=" magit-read-remote)
-             (?r "Refspec" "--used-refspec=" read-from-minibuffer))
+             (?r "Refspec" "--used-refspec="))
   :default-action 'magit-annex-unused)
 
 (magit-define-popup magit-annex-list-popup
@@ -300,9 +302,11 @@ With a prefix argument, prompt for FILE.
     (--when-let (magit-current-section)
       (pcase (list (magit-diff-type) (magit-diff-scope))
         (`(untracked file)
-         (magit-annex-run "add" (magit-section-value it)))
+         (magit-annex-run "add" (directory-file-name
+                                 (magit-section-value it))))
         (`(untracked files)
-         (magit-annex-run "add" (magit-region-values)))
+         (magit-annex-run "add" (mapcar #'directory-file-name
+                                        (magit-region-values))))
         (`(untracked list)
          (magit-annex-run "add" (magit-untracked-files)))
         (`(unstaged file)
